Consent class
Properties
-
consented
↔ bool
-
Whether the user consented to data collection
getter/setter pair
-
document
↔ String?
-
The data collection document to which the user consented or did not consent
getter/setter pair
-
hardwareId
↔ String?
-
The device ID associated with this consent record
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
location
↔ String?
-
Where the consent prompt took place. This can be a physical or digital location (e.g. URL)
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
timestamp
↔ int?
-
Timestamp when the user was prompted for consent
getter/setter pair
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited