CommerceEvent class

A commerce event

A commerce event can either contain Products, Promotions, or Impressions.

Constructors

CommerceEvent.withImpression({required Impression impression})
Initializes an instance of MPCommerceEvent with a product impression.
CommerceEvent.withProduct({required ProductActionType? productActionType, required Product product})
Initializes an instance of a Commerce Event with an action and a product.
CommerceEvent.withPromotion({required PromotionActionType? promotionActionType, required Promotion promotion})
Initializes an instance of MPCommerceEvent with a promotion container

Properties

checkoutOptions ↔ String?
The checkout option string describing what the options are.
getter/setter pair
checkoutStep ↔ int?
The step number, within the chain of commerce event transactions, corresponding to the checkout.
getter/setter pair
currency ↔ String?
The currency used in the commerce event.
getter/setter pair
customAttributes ↔ Map<String, String?>?
A map containing further information about the commerce event.
getter/setter pair
customFlags ↔ Map<String, dynamic>?
A map containing kit-specific flags about the commerce event.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
impressions → List<Impression>
A list of impressions being applied to the commerce action.
final
nonInteractive ↔ bool?
Flag indicating whether a refund is non-interactive.
getter/setter pair
productActionType → ProductActionType?
A value from the ProductActionType enum describing the commerce event action.
final
productListName ↔ String?
Describes a product action list for this commerce event transaction.
getter/setter pair
productListSource ↔ String?
Describes a product list source for this commerce event transaction.
getter/setter pair
products → List<Product>
A list of products being applied to the commerce action.
final
promotionActionType → PromotionActionType?
A value from the PromotionActionType enum describing the promotion action.
final
promotions → List<Promotion>
A list of internal promotions applied to the commerce action.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenName ↔ String?
The label describing the screen on which the commerce event transaction occurred
getter/setter pair
shouldUploadEvent ↔ bool?
Flag indicating whether the event should be sent to mParticle's servers.
getter/setter pair
transactionAttributes ↔ TransactionAttributes?
The attributes of the transaction, such as: transactionId, tax, affiliation, shipping, etc.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited