Impression class

An Impression for use with a commerce event

An Impression assigns an impressionListName to a list of products

Constructors

Impression({required String impressionListName, required List<Product> products})

Properties

hashCode → int
The hash code for this object.
no setterinherited
impressionListName ↔ String
A string name given to the list where the given Products displayed.
getter/setter pair
products ↔ List<Product>
Product(s) to be associate with the Impression.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → Impression