MPEvent class

This class represents an event to be logged using the mParticle SDK

Constructors

MPEvent({required String eventName, EventType? eventType, Map<String, String?>? customAttributes, Map<String, dynamic>? customFlags})

Properties

customAttributes ↔ Map<String, String?>?
A map containing further information about the event.
getter/setter pair
customFlags ↔ Map<String, dynamic>?
A map containing kit-specific flags about the event.
getter/setter pair
eventName ↔ String
The name of the event to be logged. The event name must not contain more than 255 characters.
getter/setter pair
eventType → EventType?
An enum value that indicates the type of event to be logged.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldUploadEvent ↔ bool?
Flag indicating whether the event should be sent to mParticle's servers.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited