Promotion class

Constructors

Promotion({required String promotionId, String? creative, String? name, String? position})

Properties

creative → String?
Description for the promotion creative
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
Promotion name
final
position → String?
Promotion display position
final
promotionId → String
Promotion identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → Promotion