TransactionAttributes class

Constructors

TransactionAttributes({required String transactionId, String? affiliation, String? couponCode, double? shipping, double? tax, double? revenue})

Properties

affiliation → String?
A string describing the affiliation.
final
couponCode → String?
The coupon code string.
final
hashCode → int
The hash code for this object.
no setterinherited
revenue → double?
The revenue amount of the commerce event transaction.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shipping → double?
The shipping amount of the commerce event transaction.
final
tax → double?
The tax amount of the commerce event transaction.
final
transactionId → String
The unique identifier for the commerce event transaction.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → TransactionAttributes