AliasRequest class

Constructors

AliasRequest({required String sourceMpid, required String destinationMpid, int? endTime, int? startTime})

Properties

destinationMpid ↔ String
The MPID of the user that should receive the copied data.
getter/setter pair
endTime ↔ int?
The timestamp of the latest data that should be copied, defaults to the source user’s last seen timestamp.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceMpid ↔ String
The MPID of the user that has existing data.
getter/setter pair
startTime ↔ int?
The timestamp of the earliest data that should be copied, defaults to the source user’s first seen timestamp.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setEndTime(dynamic endTime) → dynamic
setStartTime(dynamic startTime) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited