BoundingBox class

Padding box

Constructors

BoundingBox({required double left, required double top, required double right, required double bottom})
Initialize Bound box with LTRB padding
const

Properties

bottom → double
bottom padding
final
hashCode → int
The hash code for this object.
no setterinherited
left → double
left padding
final
right padding
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → double
top padding
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited