LayoutController class

Layout Controller to handle callbacks and Method channels of view

Constructors

LayoutController({required int id, required RoktLayoutSizeChangeCallback sizeChangeCallback, required RoktLayoutPaddingChangeCallback paddingChangeCallback})
Initialize LayoutController with a specific method channel

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → int
Id of the Rokt layout view
final
paddingChangeCallback → RoktLayoutPaddingChangeCallback
callback for the RoktLayout padding change
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeChangeCallback → RoktLayoutSizeChangeCallback
callback for the RoktLayout size change
final

Methods

dispose() → void
Dispose the controller
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited