ScreenEvent class
Properties
-
customAttributes
↔ Map<String, String?>?
-
A map containing further information about the screen event.
getter/setter pair
-
customFlags
↔ Map<String, dynamic>?
-
A map containing kit-specific flags about the screen event.
getter/setter pair
-
eventName
↔ String
-
The name of the screen event to be logged.
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited