AliasRequest class
Properties
-
destinationMpid
↔ String
-
The MPID of the user that should receive the copied data.
getter/setter pair
-
endTime
↔ int?
-
The timestamp of the latest data that should be copied, defaults to the source user’s last seen timestamp.
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
sourceMpid
↔ String
-
The MPID of the user that has existing data.
getter/setter pair
-
startTime
↔ int?
-
The timestamp of the earliest data that should be copied, defaults to the source user’s first seen timestamp.
getter/setter pair